==> exwidgets-1.0.7%2B2.tar.gz: lib/src/helper/http_config.dart <==
import 'dart:convert';
import 'package:http/http.dart' as http;

class ExHTTP {
  static String username = 'admin@anagatadev.com';
  static String password = 'Cl2TrZ7ljLCua6P3W85EVUR183eh30W7';
  static String getBasicAuth() {
    String basicAuth =
        'Basic ' + base64Encode(utf8.encode('$username:$password'));
    return basicAuth;
  }

  static dynamic get({
    String url,
    bool noHeader = false,
  }) async {
    print(url);

    var response;
    if (noHeader == false) {
      response = await http
          .get(url, headers: {'authorization': ExHTTP.getBasicAuth()});
    } else {
      response = await http.get(url);
    }

    if (response.statusCode == 200) {
      return json.decode(response.body);
    } else {
      print("HTTP ERROR");
      print(response.body);
      return null;
    }
  }

  static dynamic delete({
    String url,
    bool noHeader = false,
  }) async {
    print(url);

    var response;
    if (noHeader == false) {
      response = await http
          .delete(url, headers: {'authorization': ExHTTP.getBasicAuth()});
    } else {
      response = await http.get(url);
    }

    if (response.statusCode == 200) {
      return json.decode(response.body);
    } else {
      print("HTTP ERROR");
      print(response.body);
      return null;
    }
  }

  static dynamic post({
    String url,
    bool noHeader = false,
    dynamic data,
  }) async {
    print(url);

    var response;
    if (noHeader == false) {
      response = await http.post(
        url,
        headers: {'authorization': ExHTTP.getBasicAuth()},
        body: data
      );
    } else {
      response = await http.get(url);
    }

    if (response.statusCode == 200) {
      return json.decode(response.body);
    } else {
      print("HTTP ERROR");
      print(response.body);
      return null;
    }
  }

  static dynamic put({
    String url,
    bool noHeader = false,
    dynamic data,
  }) async {
    print(url);

    var response;
    if (noHeader == false) {
      response = await http.put(
        url,
        headers: {'authorization': ExHTTP.getBasicAuth()},
        body: data
      );
    } else {
      response = await http.get(url);
    }

    if (response.statusCode == 200) {
      return json.decode(response.body);
    } else {
      print("HTTP ERROR");
      print(response.body);
      return null;
    }
  }
}

==> exwidgets-1.0.8%2B2.tar.gz: lib/src/helper/http_config.dart <==
import 'dart:convert';
import 'package:http/http.dart' as http;

class ExHTTP {
  static String username = 'admin@anagatadev.com';
  static String password = 'Cl2TrZ7ljLCua6P3W85EVUR183eh30W7';
  static String getBasicAuth() {
    String basicAuth =
        'Basic ' + base64Encode(utf8.encode('$username:$password'));
    return basicAuth;
  }

  static dynamic get({
    String url,
    bool noHeader = false,
  }) async {
    print(url);

    var response;
    if (noHeader == false) {
      response = await http
          .get(url, headers: {'authorization': ExHTTP.getBasicAuth()});
    } else {
      response = await http.get(url);
    }

    if (response.statusCode == 200) {
      return json.decode(response.body);
    } else {
      print("HTTP ERROR");
      print(response.body);
      return null;
    }
  }

  static dynamic delete({
    String url,
    bool noHeader = false,
  }) async {
    print(url);

    var response;
    if (noHeader == false) {
      response = await http
          .delete(url, headers: {'authorization': ExHTTP.getBasicAuth()});
    } else {
      response = await http.get(url);
    }

    if (response.statusCode == 200) {
      return json.decode(response.body);
    } else {
      print("HTTP ERROR");
      print(response.body);
      return null;
    }
  }

  static dynamic post({
    String url,
    bool noHeader = false,
    dynamic data,
  }) async {
    print(url);

    var response;
    if (noHeader == false) {
      response = await http.post(url,
          headers: {
            'authorization': ExHTTP.getBasicAuth(),
            "Content-Type": "application/json",
          },
          body: data);
    } else {
      response = await http.get(url);
    }

    if (response.statusCode == 200) {
      return json.decode(response.body);
    } else {
      print("HTTP ERROR");
      print(response.body);
      return null;
    }
  }

  static dynamic put({
    String url,
    bool noHeader = false,
    dynamic data,
  }) async {
    print(url);

    var response;
    if (noHeader == false) {
      response = await http.put(url,
          headers: {
            'authorization': ExHTTP.getBasicAuth(),
            'Content-Type': 'application/json',
          },
          body: data);
    } else {
      response = await http.get(url);
    }

    if (response.statusCode == 200) {
      return json.decode(response.body);
    } else {
      print("HTTP ERROR");
      print(response.body);
      return null;
    }
  }
}
